/* dgTypeSel.c
**
** Collector module for the different message digest algorithms.
**
*/

#include <stdio.h>

/* Every `#include' at this point refers to a single message digest algorithm.
** Every extension of the `digest'-module should be done here.
*/

#include "md4.h"
#include "md5.h"
#include "sha1.h"

/* End of the includes for the single message digest algorithms... */

#include "dgTypeSel.h"

/* Each entry for a message digest algorithm consists of six entries:
**   1. the name of the algorithm,
**   2. the size of the context structure used in the corresponding
**      algorithm,
**   3. the length of the resulting digest,
**   4. a pointer to the update function of the message digest algorithm,
**   5. a pointer to the init function of the message digest algorithm,
**   6. a pointer to the final function of the message digest algorithm
**      - this function returns the message digest in it's first algorithm.
*/
struct dgTypeSel dgtrans[] = {
    { "MD4", sizeof(MD4_CTX), 16,
	     (update_ft)MD4Update, (init_ft)MD4Init, (final_ft)MD4Final },
    { "MD5", sizeof(MD5_CTX), 16,
	     (update_ft)MD5Update, (init_ft)MD5Init, (final_ft)MD5Final },
    { "SHA", sizeof(SHA1_CTX), 20,
	     (update_ft)SHA1Update, (init_ft)SHA1Init, (final_ft)SHA1Final },
    { "SHA1", sizeof(SHA1_CTX), 20,
	     (update_ft)SHA1Update, (init_ft)SHA1Init, (final_ft)SHA1Final },
    { NULL, (size_t) 0, 0, (update_ft) NULL, (init_ft) NULL, (final_ft) NULL }
};
